Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
SSVC Rust Implementation
A Rust implementation of the SSVC (Stakeholder-Specific Vulnerability Categorization) specification. SSVC is a framework for prioritizing software vulnerability remediation efforts. It helps stakeholders make informed decisions about which vulnerabilities to address first by considering factors like vulnerability severity, the stakeholder's position in the ecosystem, and their specific constraints. Learn more at the official SSVC documentation.
Features
This library provides validation and processing of SSVC decision points and selection lists, with support for SSVC namespaces and extensions. It features full serde support. The library supports both native Rust usage and WebAssembly (WASM) bindings for JavaScript/web applications.
Installation
Add to your project:
MSRV
1.85.0
Examples
Rust
use SelectionList;
use validate_selection_list;
let json_data = "..."; // Your SSVC selection list
let selection_list: SelectionList =
from_str.expect;
// Validate the selection list
let result = validate_selection_list;
if result.success else
WebAssembly
Build
# Install wasm-pack if you haven't already
# Build for web
Usage
import * as wasm from './pkg/ssvc.js';
const jsonData = ; // Your SSVC selection list
try catch
License
Licensed under the Apache License, Version 2.0. See LICENSE file for details.